@@ -1,16 +1,20 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2019 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-use strict;
-use warnings;
+# This code is part of distribution Mail-Message.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '3.005';
+$VERSION = '3.008';
 
 use base 'Mail::Reporter';
 
+use strict;
+use warnings;
+
 use Mail::Message::Part ();
 use Mail::Message::Head::Complete ();
 use Mail::Message::Construct ();
@@ -20,7 +24,7 @@ use Mail::Message::Body::Multipart ();
 use Mail::Message::Body::Nested ();
 
 use Carp;
-use Scalar::Util   'weaken';
+use Scalar::Util   qw(weaken blessed);
 
 BEGIN {
     unless($ENV{HARNESS_ACTIVE}) {   # no tests during upgrade
@@ -497,11 +501,17 @@ my $email_simple_converter;
 sub coerce($@)
 {   my ($class, $message) = @_;
 
-    ref $message
+    blessed $message
         or die "coercion starts with some object";
 
-    return bless $message, $class
-        if $message->isa(__PACKAGE__);
+	return $message
+		if ref $message eq $class;
+
+    if($message->isa(__PACKAGE__)) {
+        $message->head->modified(1);
+        $message->body->modified(1);
+        return bless $message, $class;
+	}
 
     if($message->isa('MIME::Entity'))
     {   unless($mime_entity_converter)
@@ -622,11 +632,11 @@ sub readBody($$;$$)
         {   $bodytype = $nbody  }
 
         $body = $bodytype->new
-        ( message => $self
-        , checked => $self->{MM_trusted}
-        , charset => 'us-ascii'
-        , $self->logSettings
-        );
+          ( message => $self
+          , checked => $self->{MM_trusted}
+          , charset => 'us-ascii'
+          , $self->logSettings
+          );
 
         $body->contentInfoFrom($head);
     }
