@@ -1,10 +1,14 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2019 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
+# This code is part of distribution Mail-Message.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '3.005';
+$VERSION = '3.008';
 
 
 use strict;
@@ -83,7 +87,7 @@ sub build(@)
         elsif($key =~ m/^[A-Z]/)
         {   push @headerlines, $key, $value }
         else
-        {   $class->log(WARNING => "Skipped unknown key $key in build");
+        {   $class->log(WARNING => "Skipped unknown key '$key' in build");
         }
 
         push @parts, grep defined, @data;
