@@ -1,18 +1,21 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2019 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-use strict;
-use warnings;
+# This code is part of distribution Mail-Message.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Message::Field::Attribute;
 use vars '$VERSION';
-$VERSION = '3.005';
+$VERSION = '3.008';
 
 use base 'Mail::Reporter';
-use 5.007003;
-use Encode ();
 
+use strict;
+use warnings;
+
+use Encode ();
 use Carp;
 
 
@@ -49,8 +52,8 @@ sub init($$)
     $self->{MMFF_charset}  = $args->{charset}  if defined $args->{charset};
     $self->{MMFF_language} = $args->{language} if defined $args->{language};
 
-    $self->value(defined $value ? $value : '');
-    $self->addComponent($attr) unless $attr eq $name;
+    $self->value(defined $value ? "$value" : '');  # enforce stringification
+    $self->addComponent($attr) if $attr ne $name;
 
     $self;
 }
